import { BaseFieldProps } from 'web-utility';
import { WebCellProps } from './utility';
import { WebCellClass, WebCellComponent } from './WebCell';
export interface WebFieldProps extends BaseFieldProps, WebCellProps {
}
export interface WebFieldComponent<P extends WebFieldProps = WebFieldProps, S = {}> extends WebCellComponent<P, S> {
    /**
     * Called when the browser associates the element with a form element,
     * or disassociates the element from a form element.
     */
    formAssociatedCallback?(form: HTMLFormElement): void;
    /**
     * Called after the disabled state of the element changes,
     * either because the disabled attribute of this element was added or removed;
     * or because the disabled state changed on a `<fieldset>` that's an ancestor of this element.
     *
     * @param disabled This parameter represents the new disabled state of the element.
     */
    formDisabledCallback?(disabled: boolean): void;
    /**
     * Called after the form is reset.
     * The element should reset itself to some kind of default state.
     */
    formResetCallback?(): void;
    /**
     * Called in one of two circumstances:
     *   - When the browser restores the state of the element (for example, after a navigation, or when the browser restarts). The `mode` argument is `"restore"` in this case.
     *   - When the browser's input-assist features such as form autofilling sets a value. The `mode` argument is `"autocomplete"` in this case.
     *
     * @param state The type of this argument depends on how the `this.internals.setFormValue()` method was called.
     * @param mode
     */
    formStateRestoreCallback?(state: string | File | FormData, mode: 'restore' | 'autocomplete'): void;
}
export interface WebFieldClass<P extends WebFieldProps = WebFieldProps, S = {}> extends WebCellClass<P, S> {
    new (options?: ShadowRootInit): WebFieldComponent<P, S>;
}
export declare function mixinForm<P extends WebFieldProps = WebFieldProps, S = {}>(superClass?: {
    new (): HTMLElement;
    prototype: HTMLElement;
}): WebFieldClass<P, S>;
